@@ -26,7 +26,7 @@
 #include "gproxyresolvergnome.h"
 
 
-void
+G_MODULE_EXPORT void
 g_io_gnomeproxy_load (GIOModule *module)
 {
   gchar *locale_dir;
@@ -49,12 +49,12 @@ g_io_gnomeproxy_load (GIOModule *module)
   g_free (locale_dir);
 }
 
-void
+G_MODULE_EXPORT void
 g_io_gnomeproxy_unload (GIOModule *module)
 {
 }
 
-gchar **
+G_MODULE_EXPORT gchar **
 g_io_gnomeproxy_query (void)
 {
   gchar *eps[] = {
