@@ -22,8 +22,7 @@
  * exception applies. Refer to the LICENSE_EXCEPTION file for details.
  */
 
-#ifndef __G_TLS_CERTIFICATE_GNUTLS_H__
-#define __G_TLS_CERTIFICATE_GNUTLS_H__
+#pragma once
 
 #include <gio/gio.h>
 #include <gnutls/abstract.h>
@@ -33,18 +32,7 @@ G_BEGIN_DECLS
 
 #define G_TYPE_TLS_CERTIFICATE_GNUTLS            (g_tls_certificate_gnutls_get_type ())
 
-G_DECLARE_DERIVABLE_TYPE (GTlsCertificateGnutls, g_tls_certificate_gnutls, G, TLS_CERTIFICATE_GNUTLS, GTlsCertificate)
-
-struct _GTlsCertificateGnutlsClass
-{
-  GTlsCertificateClass parent_class;
-
-  void              (*copy)               (GTlsCertificateGnutls    *gnutls,
-                                           const gchar              *interaction_id,
-                                           gnutls_pcert_st         **pcert,
-                                           unsigned int             *pcert_length,
-                                           gnutls_privkey_t         *pkey);
-};
+G_DECLARE_FINAL_TYPE (GTlsCertificateGnutls, g_tls_certificate_gnutls, G, TLS_CERTIFICATE_GNUTLS, GTlsCertificate)
 
 GTlsCertificate *            g_tls_certificate_gnutls_new             (const gnutls_datum_t  *datum,
                                                                        GTlsCertificate       *issuer);
@@ -82,5 +70,3 @@ GTlsCertificateGnutls*       g_tls_certificate_gnutls_build_chain     (const gnu
                                                                        gnutls_x509_crt_fmt_t  format);
 
 G_END_DECLS
-
-#endif /* __G_TLS_CERTIFICATE_GNUTLS_H___ */
